@@ -1,6 +1,6 @@
 /* font-manager-string-set.c
  *
- * Copyright (C) 2009-2024 Jerry Casiano
+ * Copyright (C) 2009-2025 Jerry Casiano
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -155,9 +155,11 @@ void
 font_manager_string_set_add_all (FontManagerStringSet *self, FontManagerStringSet *add)
 {
     g_return_if_fail(self != NULL);
+    g_object_freeze_notify(G_OBJECT(self));
     guint n_strings = font_manager_string_set_size(add);
     for (guint i = 0; i < n_strings; i++)
         font_manager_string_set_add(self, font_manager_string_set_get(add, i));
+    g_object_thaw_notify(G_OBJECT(self));
     return;
 }
 
@@ -171,7 +173,8 @@ font_manager_string_set_add_all (FontManagerStringSet *self, FontManagerStringSe
 gboolean
 font_manager_string_set_contains (FontManagerStringSet *self, const gchar *str)
 {
-    g_return_val_if_fail(self != NULL && str != NULL, FALSE);
+    if (!self || !str || font_manager_string_set_size(self) < 1)
+        return FALSE;
     FontManagerStringSetPrivate *priv = font_manager_string_set_get_instance_private(self);
     return g_ptr_array_find_with_equal_func(priv->strings, str, (GEqualFunc) g_str_equal, NULL);
 }
@@ -220,9 +223,11 @@ void
 font_manager_string_set_remove_all (FontManagerStringSet *self, FontManagerStringSet *remove)
 {
     g_return_if_fail(self != NULL);
+    g_object_freeze_notify(G_OBJECT(self));
     guint n_strings = font_manager_string_set_size(remove);
     for (guint i = 0; i < n_strings; i++)
         font_manager_string_set_remove(self, font_manager_string_set_get(remove, i));
+    g_object_thaw_notify(G_OBJECT(self));
     return;
 }
 
